build_key

Function build_key 

pub fn build_key(prefix: &str, sig: &[String]) -> String
Build a colon-joined key from a family prefix and significant tokens, falling back to default when there are none.